@@ -262,50 +262,54 @@ static void _xfdashboard_actor_on_mapped_changed(GObject *inObject,
 			/* Set flag that first-time visible happened at this actor */
 			priv->firstTimeMapped=TRUE;
 
-			/* Set up default initial values for animation */
-			initials=xfdashboard_animation_defaults_new(4,
-														"x", G_TYPE_FLOAT, 0.0f,
-														"y", G_TYPE_FLOAT, 0.0f,
-														"width", G_TYPE_FLOAT, 0.0f,
-														"height", G_TYPE_FLOAT, 0.0f);
-
-			/* Set up default final values for animation */
-			clutter_actor_get_allocation_box(CLUTTER_ACTOR(self), &finalBox);
-			finals=xfdashboard_animation_defaults_new(4,
-														"x", G_TYPE_FLOAT, finalBox.x1,
-														"y", G_TYPE_FLOAT, finalBox.y1,
-														"width", G_TYPE_FLOAT, clutter_actor_box_get_width(&finalBox),
-														"height", G_TYPE_FLOAT, clutter_actor_box_get_height(&finalBox));
-
-			/* Lookup animation for create signal and set up values for allocation */
-			priv->firstTimeMappedAnimation=xfdashboard_animation_new_with_values(self, "created", initials, finals);
-
-			/* Free default initial and final values */
-			xfdashboard_animation_defaults_free(initials);
-			xfdashboard_animation_defaults_free(finals);
-
-			/* Run animation if found */
-			if(!priv->firstTimeMappedAnimation ||
-				!xfdashboard_animation_get_id(priv->firstTimeMappedAnimation) ||
-				xfdashboard_animation_is_empty(priv->firstTimeMappedAnimation))
+			/* If an animation for "created" signal exists, then set up animation */
+			if(xfdashboard_animation_has_animation(self, "created"))
 			{
-				/* Empty or invalid animation, so release allocated resources and return */
-				if(priv->firstTimeMappedAnimation) g_object_unref(priv->firstTimeMappedAnimation);
-				priv->firstTimeMappedAnimation=NULL;
+				/* Set up default initial values for animation */
+				initials=xfdashboard_animation_defaults_new(4,
+															"x", G_TYPE_FLOAT, 0.0f,
+															"y", G_TYPE_FLOAT, 0.0f,
+															"width", G_TYPE_FLOAT, 0.0f,
+															"height", G_TYPE_FLOAT, 0.0f);
 
-				return;
+				/* Set up default final values for animation */
+				xfdashboard_actor_get_allocation_box(self, &finalBox);
+				finals=xfdashboard_animation_defaults_new(4,
+															"x", G_TYPE_FLOAT, finalBox.x1,
+															"y", G_TYPE_FLOAT, finalBox.y1,
+															"width", G_TYPE_FLOAT, clutter_actor_box_get_width(&finalBox),
+															"height", G_TYPE_FLOAT, clutter_actor_box_get_height(&finalBox));
+
+				/* Lookup animation for create signal and set up values for allocation */
+				priv->firstTimeMappedAnimation=xfdashboard_animation_new_with_values(self, "created", initials, finals);
+
+				/* Free default initial and final values */
+				xfdashboard_animation_defaults_free(initials);
+				xfdashboard_animation_defaults_free(finals);
+
+				/* Run animation if found */
+				if(!priv->firstTimeMappedAnimation ||
+					!xfdashboard_animation_get_id(priv->firstTimeMappedAnimation) ||
+					xfdashboard_animation_is_empty(priv->firstTimeMappedAnimation))
+				{
+					/* Empty or invalid animation, so release allocated resources and return */
+					if(priv->firstTimeMappedAnimation) g_object_unref(priv->firstTimeMappedAnimation);
+					priv->firstTimeMappedAnimation=NULL;
+
+					return;
+				}
+
+				/* Disallow allocation animation if not set in 'created' animation */
+				priv->disallowAllocationAnimation=TRUE;
+
+				/* Start animation */
+				g_signal_connect_after(priv->firstTimeMappedAnimation, "animation-done", G_CALLBACK(_xfdashboard_actor_first_time_created_animation_done), self);
+				xfdashboard_animation_run(priv->firstTimeMappedAnimation);
+				XFDASHBOARD_DEBUG(self, ANIMATION,
+										"Found and starting animation '%s' for created signal at actor %s",
+										xfdashboard_animation_get_id(priv->firstTimeMappedAnimation),
+										G_OBJECT_TYPE_NAME(self));
 			}
-
-			/* Disallow allocation animation if not set in 'created' animation */
-			priv->disallowAllocationAnimation=TRUE;
-
-			/* Start animation */
-			g_signal_connect_after(priv->firstTimeMappedAnimation, "animation-done", G_CALLBACK(_xfdashboard_actor_first_time_created_animation_done), self);
-			xfdashboard_animation_run(priv->firstTimeMappedAnimation);
-			XFDASHBOARD_DEBUG(self, ANIMATION,
-									"Found and starting animation '%s' for created signal at actor %s",
-									xfdashboard_animation_get_id(priv->firstTimeMappedAnimation),
-									G_OBJECT_TYPE_NAME(self));
 		}
 	}
 }
@@ -1122,10 +1126,17 @@ static void _xfdashboard_actor_on_allocation_changed(ClutterActor *inActor,
 	priv=self->priv;
 
 	/* Track allocation changes */
-	priv->allocationTrackBox->x1=inAllocationBox->x1;
-	priv->allocationTrackBox->x2=inAllocationBox->x2;
-	priv->allocationTrackBox->y1=inAllocationBox->y1;
-	priv->allocationTrackBox->y2=inAllocationBox->y2;
+	if(G_LIKELY(priv->allocationTrackBox))
+	{
+		priv->allocationTrackBox->x1=inAllocationBox->x1;
+		priv->allocationTrackBox->x2=inAllocationBox->x2;
+		priv->allocationTrackBox->y1=inAllocationBox->y1;
+		priv->allocationTrackBox->y2=inAllocationBox->y2;
+	}
+		else
+		{
+			priv->allocationTrackBox=clutter_actor_box_copy(inAllocationBox);
+		}
 
 		/* Check if allocation animation was requested explicitly */
 	if(priv->doAllocationAnimation &&
@@ -1655,7 +1666,7 @@ void xfdashboard_actor_init(XfdashboardActor *self)
 	priv->doAllocationAnimation=FALSE;
 	priv->allocationAnimation=NULL;
 	priv->allocationInitialBox=NULL;
-	priv->allocationTrackBox=clutter_actor_box_new(0, 0, 0, 0);
+	priv->allocationTrackBox=NULL;
 
 	/* Connect signals */
 	g_signal_connect(self, "notify::mapped", G_CALLBACK(_xfdashboard_actor_on_mapped_changed), NULL);
@@ -1934,9 +1945,47 @@ void xfdashboard_actor_enable_allocation_animation_once(XfdashboardActor *self)
 		priv->allocationInitialBox=NULL;
 	}
 
+	if(G_UNLIKELY(!priv->allocationTrackBox))
+	{
+		priv->allocationTrackBox=clutter_actor_box_new(0.0f, 0.0f, 0.0f, 0.0f);
+	}
+
 	priv->allocationInitialBox=clutter_actor_box_copy(priv->allocationTrackBox);
 }
 
+/* Calling clutter_actor_get_allocation_box() is dangerous with animationa
+ * because it may modify the internal state of the position and size of
+ * an actor used for initial values for position and size at the animation
+ * to run. Therefore this safe function exists which returns the last allocation
+ * set to this actor.
+ */
+void xfdashboard_actor_get_allocation_box(XfdashboardActor *self, ClutterActorBox *outAllocationBox)
+{
+	XfdashboardActorPrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_ACTOR(self));
+
+	priv=self->priv;
+
+	/* Get current allocation box from actor the unsafe way if tracked allocation box
+	 * must be initialized.
+	 */
+	if(G_UNLIKELY(!priv->allocationTrackBox))
+	{
+		priv->allocationTrackBox=clutter_actor_box_new(0.0f, 0.0f, 0.0f, 0.0f);
+		clutter_actor_get_allocation_box(CLUTTER_ACTOR(self), priv->allocationTrackBox);
+	}
+
+	/* Copy tracked allocation box to result */
+	if(G_LIKELY(outAllocationBox))
+	{
+		outAllocationBox->x1=priv->allocationTrackBox->x1;
+		outAllocationBox->x2=priv->allocationTrackBox->x2;
+		outAllocationBox->y1=priv->allocationTrackBox->y1;
+		outAllocationBox->y2=priv->allocationTrackBox->y2;
+	}
+}
+
 /* Destroys an actor but checks first if an animation should be played.
  * If an animation for this actor exists, it will be played and after it
  * has ended, it will be destroyed. If no animation exists, the actor will
