@@ -360,37 +360,37 @@ static void xfdashboard_view_class_init(XfdashboardViewClass *klass)
 	/* Define properties */
 	XfdashboardViewProperties[PROP_VIEW_ID]=
 		g_param_spec_string("view-id",
-							_("View ID"),
-							_("The internal ID used to register this type of view"),
+							"View ID",
+							"The internal ID used to register this type of view",
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
 	XfdashboardViewProperties[PROP_VIEW_NAME]=
 		g_param_spec_string("view-name",
-							_("View name"),
-							_("Name of view used to display"),
+							"View name",
+							"Name of view used to display",
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardViewProperties[PROP_VIEW_ICON]=
 		g_param_spec_string("view-icon",
-							_("View icon"),
-							_("Icon of view used to display. Icon name can be a themed icon name or file name"),
+							"View icon",
+							"Icon of view used to display. Icon name can be a themed icon name or file name",
 							NULL,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardViewProperties[PROP_VIEW_FIT_MODE]=
 		g_param_spec_enum("view-fit-mode",
-							_("View fit mode"),
-							_("Defines if view should be fit into viewpad and in which directions it should fit into it"),
+							"View fit mode",
+							"Defines if view should be fit into viewpad and in which directions it should fit into it",
 							XFDASHBOARD_TYPE_VIEW_FIT_MODE,
 							XFDASHBOARD_VIEW_FIT_MODE_NONE,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardViewProperties[PROP_ENABLED]=
 		g_param_spec_boolean("enabled",
-								_("Enabled"),
-								_("This flag indicates if is view is enabled and activable"),
+								"Enabled",
+								"This flag indicates if is view is enabled and activable",
 								TRUE,
 								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
