@@ -128,7 +128,7 @@ static void _xfdashboard_window_tracker_backend_x11_on_stage_active_window_chang
 	stageWnckWindow=xfdashboard_window_tracker_window_x11_get_window(stageWindow);
 	if(!stageWnckWindow)
 	{
-		g_critical(_("Could not get real stage window to handle signal 'active-window-changed'"));
+		g_critical("Could not get real stage window to handle signal 'active-window-changed'");
 		return;
 	}
 
@@ -190,7 +190,7 @@ static void _xfdashboard_window_tracker_backend_x11_on_stage_screen_size_changed
 	 */
 	if(!wnck_screen_net_wm_supports(wnck_window_get_screen(stageWindow), "_NET_WM_FULLSCREEN_MONITORS"))
 	{
-		g_warning(_("Keep window fullscreen on primary monitor because window manager does not support _NET_WM_FULLSCREEN_MONITORS."));
+		g_warning("Keep window fullscreen on primary monitor because window manager does not support _NET_WM_FULLSCREEN_MONITORS.");
 		return;
 	}
 
@@ -440,7 +440,7 @@ static ClutterStage* _xfdashboard_window_tracker_backend_x11_window_tracker_back
 							"Could not get wnck window for window %s@%p",
 							G_OBJECT_TYPE_NAME(stageWindow),
 							stageWindow);
-		g_critical(_("Could not get real stage window to find stage"));
+		g_critical("Could not get real stage window to find stage");
 		return(NULL);
 	}
 
@@ -453,7 +453,7 @@ static ClutterStage* _xfdashboard_window_tracker_backend_x11_window_tracker_back
 							stageWnckWindow,
 							G_OBJECT_TYPE_NAME(stageWindow),
 							stageWindow);
-		g_critical(_("Could not get real stage window to find stage"));
+		g_critical("Could not get real stage window to find stage");
 		return(NULL);
 	}
 
@@ -499,7 +499,7 @@ static void _xfdashboard_window_tracker_backend_x11_window_tracker_backend_show_
 	stageWnckWindow=xfdashboard_window_tracker_window_x11_get_window(stageWindow);
 	if(!stageWnckWindow)
 	{
-		g_critical(_("Could not get real stage window to show"));
+		g_critical("Could not get real stage window to show");
 		return;
 	}
 
@@ -611,7 +611,7 @@ static void _xfdashboard_window_tracker_backend_x11_window_tracker_backend_hide_
 	stageWnckWindow=xfdashboard_window_tracker_window_x11_get_window(stageWindow);
 	if(!stageWnckWindow)
 	{
-		g_critical(_("Could not get real stage window to hide"));
+		g_critical("Could not get real stage window to hide");
 		return;
 	}
 
